Versions
========

0.0.5
======

_Release date: 2020-04-26_

- Disable 'pylint' for unittests
- Define public interfaces on the package level

0.0.4
======

_Release date: 2020-03-24_

- Use 'enforce-pep8' package

0.0.3
========

_Release date: 2020-03-23_

- Update codefactor badge
- Add 'travis CI' to tools
- Update organisation budges
- Style release dates
- Count amount of package downloads

0.0.2
========

_Release date: 2020-03-25_

- Create logged http session interface
- Implement credentials interface

0.0.1
========

_Release date: 2020-03-24_

- Create package setup procedure
- Describe usage in readme file
- Include HTTP session unittests
- Introduce 'uyaml' package
- Cover project with unittests
- Implement URLs support
- Implement HTTP responses
- Implement HTTP sessions
- Present initial 'urequest' package
